@@ -22,7 +22,8 @@ from idm_lp.commands import (
     run_eval,
     self_signal,
     set_secret_code,
-    sloumo
+    sloumo,
+    timers
 )
 
 commands_bp = (
@@ -50,5 +51,7 @@ commands_bp = (
     set_secret_code.user,
     sloumo.user,
 
+    timers.user,
+
     *members_manager.users_bp,
 )
