@@ -1,10 +1,11 @@
 from .alias import Alias
 from .chat_enter import ChatEnterModel
-from .ignored_members import IgnoredMembers, IgnoredGlobalMembers, MutedMembers
+from .ignored_members import IgnoredMembers, MutedMembers
 from .mixins import ContextInstanceMixin
 from .regex_deleter import RegexDeleter
 from .role_play_commands import RolePlayCommand, GenEnum
 from .sloumo import SlouMo, LastMessage
+from .timers import Timer, TimerType, TimerMethod
 from .trusted_user import TrustedUser
 
 from .errors import DatabaseError, DatabaseWarning
