@@ -1,20 +1,16 @@
-from typing import Dict
+import typing
+
 from pydantic import BaseModel
 
 __all__ = (
     'IgnoredMembers',
-    'IgnoredGlobalMembers',
     'MutedMembers',
 )
 
 
 class IgnoredMembers(BaseModel):
     member_id: int
-    chat_id: int
-
-
-class IgnoredGlobalMembers(BaseModel):
-    member_id: int
+    chat_id: typing.Optional[int]
 
 
 class MutedMembers(BaseModel):
